paidiverpy.frontend.widgets.config_general
==========================================

.. py:module:: paidiverpy.frontend.widgets.config_general

.. autoapi-nested-parse::

   Module for creating the general configuration widget in the PaidiverPy frontend.

   ..
       !! processed by numpydoc !!


Classes
-------

.. autoapisummary::

   paidiverpy.frontend.widgets.config_general.AppGeneral


Module Contents
---------------

.. py:class:: AppGeneral

   
   Class for creating the general configuration widget in the PaidiverPy frontend.
















   ..
       !! processed by numpydoc !!

   .. py:method:: create_widget() -> None

      
      Create the general configuration widget layout.
















      ..
          !! processed by numpydoc !!


